@@ -26,6 +26,7 @@ from ..utils.autoai.utils import init_cos_client, try_load_dataset
 from ..utils.autoai.errors import NoneDataConnection
 from ..utils.deployment.errors import BatchJobFailed, MissingScoringResults
 from ..wml_client_error import WMLClientError
+from ibm_watson_machine_learning.utils.autoai.enums import DataConnectionTypes
 
 if TYPE_CHECKING:
     from sklearn.pipeline import Pipeline
@@ -423,6 +424,7 @@ class Batch(BaseDeployment):
     @BaseDeployment._project_to_space_to_project
     def get_job_status(self, scoring_job_id: str) -> Dict:
         """Get status of scoring job.
+
         Parameters
         ----------
         scoring_job_id: str
@@ -457,6 +459,10 @@ class Batch(BaseDeployment):
             else:
                 conn = DataConnection._from_dict(scoring_params['output_data_reference'])
                 conn._wml_client = self._target_workspace.wml_client
+                if len(scoring_params['input_data_references']) > 1 and not self._target_workspace.wml_client.ICP:
+                    conn._obm = True
+                    if conn.type == DataConnectionTypes.S3:
+                        conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
                 return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
         else:
             raise MissingScoringResults(scoring_job_id, reason="Scoring is not completed.")
