@@ -131,6 +131,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  encoding: str = 'utf-8',
                  positive_label: str = None,
                  data_join_only: bool = False,
+                 drop_duplicates: bool = True,
                  notebooks=False,
                  autoai_pod_version=None,
                  obm_pod_version=None,
@@ -153,6 +154,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'encoding': encoding,
             'positive_label': positive_label,
             'data_join_only': data_join_only,
+            'drop_duplicates': drop_duplicates,
             'notebooks': notebooks,
             'autoai_pod_version': autoai_pod_version,
             'obm_pod_version': obm_pod_version,
