@@ -89,6 +89,7 @@ class Experiments(WMLResource):
                     >>> experiment_href = client.experiments.get_href(experiment_details)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
@@ -176,6 +177,7 @@ class Experiments(WMLResource):
                  >>> exp_details = client.experiments.update(experiment_uid, changes=metadata)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
@@ -423,6 +425,7 @@ class Experiments(WMLResource):
            >>> experiment_revision_artifact = client.experiments.create_revision(experiment_id)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
 
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -461,7 +464,7 @@ class Experiments(WMLResource):
         Experiments._validate_type(rev_uid, u'rev_uid', int, True)
         if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
-                'Not supported. Revisions APIs are supported only for WML Cloud Pack for Data 3.0 and above.')
+                'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data for Data 3.0 and above.')
         else:
             url = self._href_definitions.get_experiment_href(experiment_uid)
             return self._get_with_or_without_limit(url, limit=None, op_name="experiments",
