@@ -129,6 +129,18 @@ V4GA_CLOUD_MIGRATION_ID = u'{}/ml/v4/repository/{}'
 REMOTE_TRAINING_SYSTEM = u'{}/v4/remote_training_systems'
 REMOTE_TRAINING_SYSTEM_ID = u'{}/v4/remote_training_systems/{}'
 
+EXPORTS = u'{}/v2/asset_exports'
+EXPORT_ID = u'{}/v2/asset_exports/{}'
+EXPORT_ID_CONTENT = u'{}/v2/asset_exports/{}/content'
+
+IMPORTS = u'{}/v2/asset_imports'
+IMPORT_ID = u'{}/v2/asset_imports/{}'
+
+VOLUMES = u'{}/zen-data/v3/service_instances'
+VOLUME_ID = u'{}/zen-data/v3/service_instances/{}'
+VOLUME_SERVICE = u'{}/zen-data/v1/volumes/volume_services/{}'
+VOLUME_SERVICE_FILE_UPLOAD = u'{}/zen-volumes/{}/v1/volumes/files/'
+
 def is_url(s):
     res = re.match('https?:\/\/.+', s)
     return res is not None
@@ -493,12 +505,54 @@ class HrefDefinitions:
         else:
             return REMOTE_TRAINING_SYSTEM.format(self.platform_url)
 
+    def exports_href(self):
+        if self.platform_url is None:
+            return EXPORTS.format(self._wml_credentials['url'])
+        else:
+            return EXPORTS.format(self.platform_url)
+
+    def export_href(self, export_id):
+        if self.platform_url is None:
+            return EXPORT_ID.format(self._wml_credentials['url'], export_id)
+        else:
+            return EXPORT_ID.format(self.platform_url, export_id)
+
+    def export_content_href(self, export_id):
+        if self.platform_url is None:
+            return EXPORT_ID_CONTENT.format(self._wml_credentials['url'], export_id)
+        else:
+            return EXPORT_ID_CONTENT.format(self.platform_url, export_id)
+
+    def imports_href(self):
+        if self.platform_url is None:
+            return IMPORTS.format(self._wml_credentials['url'])
+        else:
+            return IMPORTS.format(self.platform_url)
+
+    def import_href(self, export_id):
+        if self.platform_url is None:
+            return IMPORT_ID.format(self._wml_credentials['url'], export_id)
+        else:
+            return IMPORT_ID.format(self.platform_url, export_id)
+
     def remote_training_systems_href(self):
         return REMOTE_TRAINING_SYSTEM.format(self._wml_credentials['url'] + self.prepend)
 
     def remote_training_system_href(self, remote_training_systems_id):
         return REMOTE_TRAINING_SYSTEM_ID.format(self._wml_credentials['url'] + self.prepend, remote_training_systems_id)
 
+    def volumes_href(self):
+        return VOLUMES.format(self._wml_credentials['url'])
+
+    def volume_href(self,volume_id):
+        return VOLUME_ID.format(self._wml_credentials['url'],volume_id)
+
+    def volume_service_href(self,volume_name):
+        return VOLUME_SERVICE.format(self._wml_credentials['url'],volume_name)
+
+    def volume_upload_href(self, volume_name):
+        return VOLUME_SERVICE_FILE_UPLOAD.format(self._wml_credentials['url'], volume_name)
+
     # def get_envs_href(self):
     #     return DEPLOYMENT_ENVS_HREF_PATTERN.format(self._wml_credentials['url'])
     #
