@@ -47,7 +47,9 @@ class TensorflowPipelineModelArtifact(ModelArtifact):
         lib_checker.check_lib(TENSORFLOW)
         super(TensorflowPipelineModelArtifact, self).__init__(uid, name, meta_props)
 
-        if not isinstance(tensorflow_pipeline_model,tf.Session):
+        if '2.1.0' in tf.__version__ and not isinstance(tensorflow_pipeline_model,tf.compat.v1.Session):
+            raise TypeError("sess should be of type : %s" % tf.compat.v1.Session)
+        elif not isinstance(tensorflow_pipeline_model,tf.Session):
             raise TypeError("sess should be of type : %s" % tf.Session)
 
         self.ml_pipeline_model = tensorflow_pipeline_model
