@@ -26,10 +26,8 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class ModelDefinition(WMLResource):
-
     """
     Store and manage your model_definitions.
-
     """
 
     ConfigurationMetaNames = ModelDefinitionMetaNames()
@@ -133,33 +131,31 @@ class ModelDefinition(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, model_definition, meta_props):
         """
-                   Create a model_definitions.\n
+        Create a model_definitions.\n
 
-                   **Parameters**
+        **Parameters**
 
-                   .. important::
+        .. important::
 
-                        #. **meta_props**:  meta data of the model_definition configuration. To see available meta names use:\n
-                                            >>> client.model_definitions.ConfigurationMetaNames.get()
+            #. **meta_props**:  meta data of the model_definition configuration. To see available meta names use:\n
+                >>> client.model_definitions.ConfigurationMetaNames.get()
+               **type**: dict\n
 
-                           **type**: dict\n
+            #. **model_definition**:  Path to the content file to be uploaded\n
+               **type**: str\n
 
-                       #. **model_definition**:  Path to the content file to be uploaded\n
+        **Output**
 
-                          **type**: str\n
+        .. important::
 
-                   **Output**
+            **returns**: Metadata of the model_defintion created\n
+            **return type**: dict\n
 
-                   .. important::
-
-                        **returns**: Metadata of the model_defintion created\n
-                        **return type**: dict\n
-
-                   **Example**
-
-                       >>>  client.model_definitions.store(model_definition, meta_props)
+        **Example**
 
+            >>>  client.model_definitions.store(model_definition, meta_props)
         """
+
         WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -269,10 +265,10 @@ class ModelDefinition(WMLResource):
                         # On Cloud, additional line gets added to the attachment
                         # multi form data. Use data instead
                         put_response = requests.put(model_definition_attachment_signed_url,
-                                                    data=open(model_definition, 'rb').read(),
-                                                    # files=files,
-                                                    params=paramvalue,
-                                                    headers=put_header)
+                                                    data=open(model_definition, 'rb').read())
+                                                    # # files=files,
+                                                    # params=paramvalue,
+                                                    # headers=put_header)
                     else:
 
                         put_response = requests.put(model_definition_attachment_put_url,
@@ -345,8 +341,7 @@ class ModelDefinition(WMLResource):
 
            .. important::
                 **returns**: metadata of model definition\n
-                **return type**: dict
-                dict (if model_definition_uid is not None)\n
+                **return type**: dict (if model_definition_uid is not None)\n
 
            **Example**
 
@@ -418,13 +413,14 @@ class ModelDefinition(WMLResource):
 
             **Output**
 
+            .. important::
+
                  **returns**: Path to the downloaded asset content\n
                  **return type**: str\n
 
             **Example**
 
              >>> client.script.download(asset_uid,"script_file.zip")
-
         """
 
         self._client._check_if_either_is_set()
@@ -702,7 +698,6 @@ class ModelDefinition(WMLResource):
 
                    #. **model_definition_details**:  Metadata of the stored model_definition asset\n
                       **type**: dict\n
-                      **type**: dict\n
 
                 **Output**
 
@@ -722,18 +717,25 @@ class ModelDefinition(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(self, model_definition_details):
         """
-            Get uid of stored model. Deprecated!! Use get_id(model_definition_details) instead
+        Get uid of stored model. Deprecated!! Use get_id(model_definition_details) instead
 
-            :param model_definition_details:  stored model_definition details
-            :type model_definition_details: dict
+        **Parameters**
 
-            :returns: uid of stored model_definition
-            :rtype: {str_type}
+        .. important::
 
-            A way you might use me is:
+            #. **param model_definition_details**:  stored model_definition details\n
+               **type**: dict
 
-                >>> model_definition_uid = client.model_definitions.get_uid(model_definition_details)
+        **Output**
 
+        .. important::
+
+            **returns**: uid of stored model_definition\n
+            **return type**: str\n
+
+        **Example**
+
+            >>> model_definition_uid = client.model_definitions.get_uid(model_definition_details)
         """
         if 'asset_id' in model_definition_details['metadata']:
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details',
@@ -744,20 +746,25 @@ class ModelDefinition(WMLResource):
 
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details', [u'metadata', u'guid'])
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(self, model_definition_details):
         """
-            Get href of stored model_definition.
+        Get href of stored model_definition.
 
-            :param model_definition_details:  stored model_definition details
-            :type model_definition_details: dict
+        **Parameters**
 
-            :returns: href of stored model_definition
-            :rtype: {str_type}
+        .. important::
+            #. **model_definition_details**: Stored model_definition details.\n
+               **type**: dict\n
 
-           **EXAMPLE:**
+        **Output**
 
-                >>> model_definition_uid = client.model_definitions.get_href(model_definition_details)
+        .. important::
+            **returns**: href of stored model_definition.\n
+            **return type**: str\n
 
+        **Example**
+            >>> model_definition_uid = client.model_definitions.get_href(model_definition_details)
         """
         if 'asset_id' in model_definition_details['metadata']:
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details', [u'metadata', u'asset_id'])
@@ -768,16 +775,30 @@ class ModelDefinition(WMLResource):
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details',
                                                                [u'metadata', u'href'])
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, model_definition_id, meta_props=None, file_path=None):
         """
-            Update model_definition with either metadata or attachment or both.
-            :param model_definition_id:  model_definition ID
-            :type model_definition_id: str
-            :param file_path: Path to the content file to be uploaded
-            :type file_path: str
-            :returns: updated metadata of model_definition
-            :rtype: dict
-            A way you might use me is:
+        Update model_definition with either metadata or attachment or both.\n
+
+        **Parameters**
+
+        .. important::
+
+            #. **model_definition_id**:  model_definition ID.\n
+               **type**: str\n
+
+            #. **file_path**: Path to the content file to be uploaded.\n
+               **type**: str\n
+
+        ** Output**
+
+        .. important::
+
+            **returns**: Updated metadata of model_definition.\n
+            **return type**: dict\n
+
+        **Example**
+
             >>> model_definition_details = client.model_definition.update(model_definition_id, meta_props, file_path)
         """
 
@@ -967,18 +988,29 @@ class ModelDefinition(WMLResource):
         else:
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, model_definition_uid):
         """
-           Creates revision for the given model_definition. Revisions are immutable once created.
-           The metadata and attachment at model_definition is taken and a revision is created out of it
+        Creates revision for the given model_definition. Revisions are immutable once created.
+        The metadata and attachment at model_definition is taken and a revision is created out of it.
 
-           :param model_definition: model_definition ID. Mandatory
-           :type model_definition: {str_type}
+        **Parameters**
 
-           :returns: stored model_definition revisions metadata
-           :rtype: dict
+        .. important::
 
-           >>> model_definition_revision = client.model_definitions.create_revision(model_definition_id)
+            #. **model_definition**: model_definition ID.\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: Stored model_definition revisions metadata.\n
+            **return type**: dict\n
+
+        **Example**
+
+            >>> model_definition_revision = client.model_definitions.create_revision(model_definition_id)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
 
@@ -1017,23 +1049,31 @@ class ModelDefinition(WMLResource):
             return final_response
 
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, model_definition_uid, rev_uid=None):
         """
-           Get metadata of model_definition_uid revision.
+        Get metadata of model_definit
 
-           :param model_definition_uid: model_definition ID. Mandatory
-           :type model_definition_uid: {str_type}
+        **Parameters**
 
-           :param rev_uid: Revision ID. If this parameter is not provided, returns latest revision if existing else error
-           :type rev_uid: int
+        .. important::
 
-           :returns: stored model definitions metadata
-           :rtype: dict
+            #. **model_definition_uid**: model_definition ID.\n
+               **type**: str\n
 
-           A way you might use me is:
+            #. **rev_uid**: Revision ID. If this parameter is not provided, returns latest revision if existing else error.\n
+               **type**: int\n
 
-           >>> script_details = client.model_definitions.get_revision_details(model_definition_uid, rev_uid)
+        **Output**
 
+        .. important::
+
+            **returns**: Stored model definitions metadata.\n
+            **return type**: dict\n
+
+        **Example**
+
+            >>> script_details = client.model_definitions.get_revision_details(model_definition_uid, rev_uid)
         """
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
