@@ -106,6 +106,9 @@ class Shiny(WMLResource):
                     **return type**: dict\n
 
                 **Example**
+                 >>> meta_props = {
+                 >>>    client.shiny.ConfigurationMetaNames.NAME: "shiny app name"
+                 >>> }
                  >>> asset_details = client.shiny.store(meta_props,file_path="/path/to/file")
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
