@@ -853,16 +853,28 @@ class Spaces(WMLResource):
 
     def download(self, space_uid, space_exports_uid, filename=None):
         """
-            Downloads zip file deployment of specified UID.
+        Downloads zip file deployment of specified UID.
 
-            :param exports_space_uid:  UID of virtual deployment
-            :type exports_space_uid: {str_type}
-            :param filename: filename of downloaded archive (optional)
-            :type filename: {str_type}
+        **Parameters**
 
-            :returns: path to downloaded file
-            :rtype: {str_type}
+        .. important::
 
+            #. **exports_space_uid**:  UID of virtual deployment.\n
+               **type**: str\n
+
+            #. **filename**: Filename of downloaded archive. (optional)\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: Path to downloaded file.\n
+            **return type**: str\n
+
+        **Example**
+
+         >>> client.spaces.download(space_uid)
         """
 
         space_exports_uid = str_type_conv(space_exports_uid)
