@@ -471,7 +471,7 @@ class SwSpec(WMLResource):
 
                 **Example**
 
-                >>>> client.software_specifications.delete_package_extension(sw_spec_uid, pkg_extn_id)
+                 >>> client.software_specifications.delete_package_extension(sw_spec_uid, pkg_extn_id)
 
         """
         if self._client.WSD_20:
