@@ -1,6 +1,6 @@
 import unittest
 
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.tests.Cloud.preparation_and_cleaning import *
 
 class TestFunction(unittest.TestCase):
@@ -9,7 +9,7 @@ class TestFunction(unittest.TestCase):
     function_id = None
     function_id2 = None
     scoring_url = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
