@@ -4,6 +4,7 @@ from sklearn.pipeline import Pipeline
 from lale.operators import TrainablePipeline
 from lale.lib.lale import Hyperopt
 from os import environ
+import time
 
 
 import traceback
@@ -18,8 +19,8 @@ from ibm_watson_machine_learning.deployment import WebService, Batch
 from ibm_watson_machine_learning.workspace import WorkSpace
 
 
-from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize
-from ibm_watson_machine_learning.utils.autoai.errors import AutoAIComputeError
+from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, RunStateTypes, Metrics
+from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists,\
     bucket_name_gen, get_space_id
@@ -66,8 +67,12 @@ class TestAutoAIRemote(unittest.TestCase):
     data_connection = None
     results_connection = None
 
+
     data_location = './autoai/data/xlsx/CarPrice_Assignment.xlsx'
 
+    prediction_column = 'price'
+    scoring_method = Metrics.ROOT_MEAN_SQUARED_ERROR
+
     batch_payload_location = './autoai/data/batch_payload/car_price_payload.csv'
 
     # CLOUD CONNECTION DETAILS:
@@ -192,8 +197,8 @@ class TestAutoAIRemote(unittest.TestCase):
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.REGRESSION,
-            prediction_column='price',
-            scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
+            prediction_column=self.prediction_column,
+            scoring=self.scoring_method,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             autoai_pod_version=self.pod_version
         )
@@ -206,60 +211,124 @@ class TestAutoAIRemote(unittest.TestCase):
         print(parameters)
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
-    def test_05_fit_run_training_of_auto_ai_in_wml(self):
-        failure_count = 0
-        while failure_count < 4:
-            try:
-                TestAutoAIRemote.trained_pipeline_details = self.remote_auto_pipelines.fit(
-                    training_data_reference=[self.data_connection],
-                    training_results_reference=self.results_connection,
-                    background_mode=False)
-                break
-            except AutoAIComputeError as e:
-                import time
-                failure_count += 1
-                print(f"Failure {failure_count}\n error:{e}\n\n")
-                time.sleep(10)
+    # def test_05_fit_run_training_of_auto_ai_in_wml(self):
+    #     failure_count = 0
+    #     while failure_count < 4:
+    #         try:
+    #             TestAutoAIRemote.trained_pipeline_details = self.remote_auto_pipelines.fit(
+    #                 training_data_reference=[self.data_connection],
+    #                 training_results_reference=self.results_connection,
+    #                 background_mode=False)
+    #             break
+    #         except AutoAIComputeError as e:
+    #             import time
+    #             failure_count += 1
+    #             print(f"Failure {failure_count}\n error:{e}\n\n")
+    #             time.sleep(10)
+    #
+    #     TestAutoAIRemote.run_id = self.trained_pipeline_details['metadata']['id']
+    #     self.assertIsInstance(self.trained_pipeline_details, dict,
+    #                           msg='Trained pipeline details are not a dictionary instance.')
+    #     self.assertTrue(bool(self.trained_pipeline_details))  # Checking if details are not empty.
+    #
+    #     self.assertIsNotNone(self.data_connection.auto_pipeline_params,
+    #                          msg='DataConnection auto_pipeline_params was not updated.')
+    #     TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+    #     print("train data sample:")
+    #     print(self.train_data.head())
+    #     self.assertGreater(len(self.train_data), 0)
+
+    def test_05_fit_run_training_of_auto_ai_in_wml_asynch(self):
+        TestAutoAIRemote.trained_pipeline_details = self.remote_auto_pipelines.fit(
+            training_data_reference=[self.data_connection],
+            training_results_reference=self.results_connection,
+            background_mode=True)
 
         TestAutoAIRemote.run_id = self.trained_pipeline_details['metadata']['id']
-        self.assertIsInstance(self.trained_pipeline_details, dict,
-                              msg='Trained pipeline details are not a dictionary instance.')
-        self.assertTrue(bool(self.trained_pipeline_details))  # Checking if details are not empty.
+        self.assertIsNotNone(self.run_id)
 
-        self.assertIsNotNone(self.data_connection.auto_pipeline_params,
-                             msg='DataConnection auto_pipeline_params was not updated.')
+    def test_06_get_run_status(self):
+        status = self.remote_auto_pipelines.get_run_status()
+        self.assertNotEqual(status, RunStateTypes.COMPLETED)
+
+    def test_07_get_run_details(self):
+        parameters = self.remote_auto_pipelines.get_run_details()
+        # print(parameters)
+        self.assertIsNotNone(parameters)
+
+    def test_08_get_summary(self):
+
+        print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
+        # note: check if first pipeline was generated
+
+        metrics = self.wml_client.training.get_details(self.run_id)['entity']['status'].get('metrics', [])
+        while chose_model_output("1") not in str(metrics) and self.remote_auto_pipelines.get_run_status() not in ['failed', 'canceled']:
+            time.sleep(5)
+            print(".", end=" ")
+            training_details = self.wml_client.training.get_details(self.run_id)
+            metrics = training_details['entity']['status'].get('metrics', [])
+        # end note
+
+        print("\n 1st pipeline completed")
+        summary_df = self.remote_auto_pipelines.summary()
+        print(summary_df)
+
+        self.assertGreater(len(summary_df), 0,
+                           msg=f"Summary DataFrame is empty. While {len(metrics)} pipelines are in training_details['entity']['status']['metrics']")
+
+        # check if pipelines are not duplicated
+        self.assertEqual(len(summary_df.index.unique()), len(summary_df), msg="Some pipeline names are duplicated in the summary")
+
+    def test_09_get_train_data(self):
         TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+
         print("train data sample:")
         print(self.train_data.head())
         self.assertGreater(len(self.train_data), 0)
 
-    def test_06_get_run_status(self):
+        TestAutoAIRemote.X_values = self.train_data.drop([self.prediction_column], axis=1)[:10].values
+        TestAutoAIRemote.y_values = self.train_data[self.prediction_column][:10]
+
+    def test_10_get_best_pipeline_so_far(self):
+        best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
+        print(best_pipeline_params)
+        print(best_pipeline_params)
+        self.assertIn(f"training_{self.scoring_method}", str(best_pipeline_params))
+
+        summary_df = self.remote_auto_pipelines.summary()
+        print(summary_df)
+
+        pipeline = self.remote_auto_pipelines.get_pipeline()
+        print(f"Fetched pipeline type: {type(pipeline)}")
+
+    def test_11_waiting_for_fitted_completed(self):
+        while self.remote_auto_pipelines.get_run_status() == 'running':
+            time.sleep(10)
+
         status = self.remote_auto_pipelines.get_run_status()
-        self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
 
-    def test_07_get_run_details(self):
-        parameters = self.remote_auto_pipelines.get_run_details()
-        print(parameters)
+        self.assertEqual(status, RunStateTypes.COMPLETED, msg="AutoAI run didn't finished successfully. Status: {}".format(status))
 
-    def test_08_predict_using_fitted_pipeline(self):
-        predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop(['price'], axis=1).values[:5])
+    def test_12_predict_using_fitted_pipeline(self):
+        predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop([self.prediction_column], axis=1).values[:5])
         print(predictions)
         self.assertGreater(len(predictions), 0)
 
-    def test_09_summary_listing_all_pipelines_from_wml(self):
+    def test_13_summary_listing_all_pipelines_from_wml(self):
         pipelines_details = self.remote_auto_pipelines.summary()
         print(pipelines_details)
         self.assertGreater(len(pipelines_details), 0)
 
-    def test_10_get_pipeline_params_specific_pipeline_parameters(self):
+    def test_14_get_pipeline_params_specific_pipeline_parameters(self):
         pipeline_params = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1')
-        # print(pipeline_params)
+        print(pipeline_params)
+        self.assertIn(f"holdout_{self.scoring_method}", str(pipeline_params))
 
-    def test_11_get_pipeline_params_best_pipeline_parameters(self):
+    def test_15_get_pipeline_params_best_pipeline_parameters(self):
         best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
-        # print(best_pipeline_params)
+        self.assertIn(f"holdout_{self.scoring_method}", str(best_pipeline_params))
 
-    def test_12_get_pipeline_load_specified_pipeline(self):
+    def test_16_get_pipeline_load_specified_pipeline(self):
         TestAutoAIRemote.lale_pipeline = self.remote_auto_pipelines.get_pipeline(
             pipeline_name='Pipeline_1')
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
@@ -269,7 +338,7 @@ class TestAutoAIRemote(unittest.TestCase):
     # LALE #
     ########
 
-    def test_13_get_all_pipelines_as_lale(self):
+    def test_17_get_all_pipelines_as_lale(self):
         summary = self.remote_auto_pipelines.summary()
         print(summary)
         failed_pipelines = []
@@ -319,7 +388,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_22_score_deployed_model(self):
         nb_records = 5
-        predictions = self.service.score(payload=self.train_data.drop(['price'], axis=1)[:nb_records])
+        predictions = self.service.score(payload=self.train_data.drop([self.prediction_column], axis=1)[:nb_records])
         print(predictions)
         self.assertIsNotNone(predictions)
         self.assertEqual(len(predictions['predictions'][0]['values']), nb_records)
