@@ -320,10 +320,10 @@ class TestAutoAIRemote(unittest.TestCase):
 
         runs_completed_df = runs_df[runs_df.state =='completed']
 
-        from random import randint
+        from random import randrange
         TestAutoAIRemote.random_run_id = runs_completed_df.run_id.iloc[
-            randint(1, min(5, len(runs_completed_df)))]  # random run_id first 5 rows
-        print("Random run_id from 2nd half of df: {}".format(TestAutoAIRemote.random_run_id))
+            randrange(0, min(5, len(runs_completed_df)))]  # random run_id first 5 rows
+        print("Random historical run_id: {}".format(TestAutoAIRemote.random_run_id))
         self.assertIsNotNone(TestAutoAIRemote.random_run_id)
 
     def test_16_get_params_of_last_historical_run(self):
