@@ -54,7 +54,8 @@ class TestAutoAIRemote(unittest.TestCase):
     data_connection = None
     results_connection = None
 
-    data_location = '/datasets/iris_dataset.csv'
+    dataset_name = 'iris_dataset.csv'
+    data_location = None
     custom_separator = ','
 
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
@@ -65,7 +66,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     space_name = 'tests_sdk_space'
 
-    asset_id = 'ac9f5646-a9b2-4fbf-81fc-9d289f63566f'
+    connection_id = None
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -76,13 +77,12 @@ class TestAutoAIRemote(unittest.TestCase):
         cls.wml_credentials = get_wml_credentials()
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
-        #cls.asset_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, 'iris_dataset.csv')
-        #print(cls.asset_id, cls.data_location)
+        cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
 
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name),
-                      days_old=2)
+                      days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name)
 
         self.wml_client.set.default_project(self.project_id)
@@ -94,7 +94,7 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
     def test_02_save_remote_data_and_DataConNection_setup(self):
-        TestAutoAIRemote.data_connection = DataConnection(connection=NFSConnection(asset_id=self.asset_id),
+        TestAutoAIRemote.data_connection = DataConnection(connection=NFSConnection(asset_id=self.connection_id),
                                                           location=NFSLocation(path=self.data_location))
         TestAutoAIRemote.results_connection = None
 
