@@ -17,7 +17,7 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
 from ibm_watson_machine_learning.tests.utils import print_test_separators
-from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
+from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName, OBMMainNodeAlreadySet
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
     bucket_name_gen, get_space_id
@@ -241,24 +241,33 @@ class TestOBMAndKB(unittest.TestCase):
                                          self.temp_4_conn]
 
     @print_test_separators
-    def test_02_create_data_join_graph__graph_created(self):
+    def test_02a_create_data_join_graph__graph_created(self):
         print("Defining DataJoinGraph...")
         data_join_graph = DataJoinGraph()
-        data_join_graph.node(name="main", csv_separator=",")
         data_join_graph.node(name="temp_2")
+        data_join_graph.node(name="main", csv_separator=",", main=True)
         data_join_graph.node(name="temp_3")
         data_join_graph.node(name="temp_4")
         data_join_graph.edge(from_node="main", to_node="temp_2",
-                             from_column=["time"], to_column=["time"])
+                             from_column=["device"], to_column=["device"])
         data_join_graph.edge(from_node="temp_3", to_node="main",
-                             from_column=["time"], to_column=["time"])
+                             from_column=["device"], to_column=["device"])
         data_join_graph.edge(from_node="temp_4", to_node="temp_3",
-                             from_column=["time"], to_column=["time"])
+                             from_column=["device"], to_column=["device"])
 
         TestOBMAndKB.data_join_graph = data_join_graph
 
         print(f"data_join_graph: {data_join_graph}")
 
+    @print_test_separators
+    def test_02b_create_data_join_graph__more_main_nodes__creation_failed(self):
+        print("Defining DataJoinGraph...")
+        data_join_graph = DataJoinGraph()
+        data_join_graph.node(name="temp_2")
+        data_join_graph.node(name="main", csv_separator=",", main=True)
+        with self.assertRaises(OBMMainNodeAlreadySet, msg="Check of OBM main node failed!"):
+            data_join_graph.node(name="temp_3", main=True)
+
     # @print_test_separators
     # def test_03_data_join_graph_visualization(self):
     #     print("Visualizing data_join_graph...")
@@ -383,6 +392,12 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.run_id = self.trained_pipeline_details['metadata']['id']
 
         TestOBMAndKB.pipeline_name = 'Pipeline_4'
+
+        run_status = self.remote_auto_pipelines.get_run_status()
+        print(f"Run ended with status:  {run_status}")
+
+        self.assertEqual(run_status, "completed", msg=f"Obm training has not finished succesfully. More info: {self.trained_pipeline_details['entity'].get('status')}")
+
         TestOBMAndKB.model_location = self.trained_pipeline_details['entity']['status']['metrics'][-1]['context']['intermediate_model']['location']['model']
         TestOBMAndKB.training_status = self.trained_pipeline_details['entity']['results_reference']['location']['training_status']
 
@@ -413,13 +428,14 @@ class TestOBMAndKB(unittest.TestCase):
         self.assertGreater(len(self.train_data), 0)
 
 
-    # @print_test_separators
-    # def test_11_visualize_obm_pipeline(self):
-    #     print("Visualizing OBM model ...")
-    #     TestOBMAndKB.data_join_pipeline = self.remote_auto_pipelines.get_preprocessing_pipeline()
-    #     assert isinstance(self.data_join_pipeline._pipeline_json, list)
-    #     assert '40 [label=NumberSet]' in self.data_join_pipeline._graph.__str__()
-    # #     self.data_join_pipeline.visualize()
+    @print_test_separators
+    def test_11_visualize_obm_pipeline(self):
+        print("Visualizing OBM model ...")
+        TestOBMAndKB.data_join_pipeline = self.remote_auto_pipelines.get_preprocessing_pipeline()
+        assert isinstance(self.data_join_pipeline._pipeline_json, list)
+        str_graph = self.data_join_pipeline._graph.__str__()
+        assert '[label="temp>=31"]' in self.data_join_pipeline._graph.__str__()
+    #     self.data_join_pipeline.visualize()
 
     @print_test_separators
     def test_11b_check_if_data_join_pipeline_graph_correct(self):
@@ -516,6 +532,8 @@ class TestOBMAndKB(unittest.TestCase):
     def test_19__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
         print("Download and load Pipeline_4 as lale...")
         TestOBMAndKB.lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
 
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline,
@@ -532,6 +550,8 @@ class TestOBMAndKB(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                self.assertWarnsRegex(Warning, "OBM",
+                                      msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(X=self.train_data.drop([self.prediction_column], axis=1).values[:1])
                 print(predictions)
@@ -585,6 +605,8 @@ class TestOBMAndKB(unittest.TestCase):
     def test_20c_get_pipeline_from_hyperopt(self):
         print("Get locally optimized pipeline...")
         new_pipeline_model = TestOBMAndKB.hyperopt_pipelines.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Hyperopt_pipeline_model is type: {type(new_pipeline_model)}")
         TestOBMAndKB.new_sklearn_pipeline = new_pipeline_model.export_to_sklearn_pipeline()
         self.assertIsInstance(
@@ -606,6 +628,8 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4',
                                                                         astype=self.experiment.PipelineTypes.SKLEARN)
         print(f"Fetched pipeline type: {type(self.pipeline)}")
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
         self.assertIsInstance(self.pipeline, Pipeline,
                               msg="Fetched pipeline is not of sklearn.Pipeline instance.")
@@ -626,6 +650,8 @@ class TestOBMAndKB(unittest.TestCase):
                               msg="data_join_graph was incorrectly loaded")
 
         TestOBMAndKB.pipeline = self.historical_opt.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
     @print_test_separators
     def test_25_get_obm_training_data_from_historical_optimizer(self):
