@@ -86,30 +86,30 @@ class Training(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, training_uid=None, limit=None):
         """
-           Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
+        Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
 
-           **Parameters**
+        **Parameters**
 
-            .. important::
-                #. **training_uid**: Unique Id of Training (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
+        .. important::
+            #. **training_uid**: Unique Id of Training (optional)\n
+               **type**: str\n
+            #. **limit**:  limit number of fetched records (optional)\n
+               **type**: int\n
 
-           **Output**
+        **Output**
 
-            .. important::
-                **returns**: metadata of training(s)\n
-                **return type**: dict
-                The output can be {"resources": [dict]} or a dict\n
+        .. important::
+            **returns**: metadata of training(s)\n
+            **return type**: dict\n
+            The output can be {"resources": [dict]} or a dict\n
 
-           .. note::
-                If training_uid is not specified, all trainings metadata is fetched\n
+        .. note::
+            If training_uid is not specified, all trainings metadata is fetched\n
 
-           **Example**
+        **Example**
 
-            >>> training_run_details = client.training.get_details(training_uid)
-            >>> training_runs_details = client.training.get_details()
+         >>> training_run_details = client.training.get_details(training_uid)
+         >>> training_runs_details = client.training.get_details()
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -213,116 +213,115 @@ class Training(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def run(self, meta_props, asynchronous=True):
         """
-            Create a new Machine Learning training.
+        Create a new Machine Learning training.
 
-            **Parameters**
+        **Parameters**
 
-                .. important::
+        .. important::
 
-                    #. **meta_props**:  meta data of the training configuration. To see available meta names use:\n
-                            >>> client.training.ConfigurationMetaNames.show()
+            #. **meta_props**:  meta data of the training configuration. To see available meta names use:\n
+               >>> client.training.ConfigurationMetaNames.show()
 
-                       **type**: str\n
+               **type**: str\n
 
-                    #. **asynchronous**:
-                        * True  - training job is submitted and progress can be checked later.\n
-                        * False - method will wait till job completion and print training stats.\n
-                       **type**: bool\n
+            #. **asynchronous**:\n
+               * True  - training job is submitted and progress can be checked later.\n
+               * False - method will wait till job completion and print training stats.\n
+               **type**: bool\n
 
 
-            **Output**
+        **Output**
 
-                .. important::
+        .. important::
 
-                    **returns**: Metadata of the training created\n
-                    **return type**: dict\n
+            **returns**: Metadata of the training created\n
+            **return type**: dict\n
 
-            **Examples**
-                    **Example meta_props for Training run creation in IBM Cloud Pak® for Data for Data version 3.0.1 or above:
-                    >>> metadata = {
-                    >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
-                    >>>  client.training.ConfigurationMetaNames.DESCRIPTION: 'Hand-written Digit Recognition Training',
-                    >>>  client.training.ConfigurationMetaNames.PIPELINE: {
-                    >>>                "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
-                    >>>                "rev": "12",
-                    >>>                "model_type": "string",
-                    >>>                "data_bindings": [
-                    >>>                  {
-                    >>>                    "data_reference_name": "string",
-                    >>>                    "node_id": "string"
-                    >>>                  }
-                    >>>                ],
-                    >>>                "nodes_parameters": [
-                    >>>                  {
-                    >>>                    "node_id": "string",
-                    >>>                    "parameters": {}
-                    >>>                  }
-                    >>>                ],
-                    >>>                "hardware_spec": {
-                    >>>                  "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
-                    >>>                  "rev": "12",
-                    >>>                  "name": "string",
-                    >>>                  "num_nodes": "2"
-                    >>>                }
-                    >>>      },
-                    >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
-                    >>>          'type': 's3',
-                    >>>          'connection': {},
-                    >>>          'location': {
-                    >>>              'href': 'v2/assets/asset1233456',
-                    >>>          }
-                    >>>          "schema": "{ \"id\": \"t1\", \"name\": \"Tasks\", \"fields\": [ { \"name\": \"duration\", \"type\": \"number\" } ]}"
-                    >>>      }],
-                    >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
-                    >>>          'id' : 'string',
-                    >>>          'connection': {
-                    >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-                    >>>              'access_key_id': '***',
-                    >>>              'secret_access_key': '***'
-                    >>>          },
-                    >>>          'location': {
-                    >>>              'bucket': 'wml-dev-results',
-                    >>>               'path' : "path"
-                    >>>          }
-                    >>>          'type': 's3'
-                    >>>      }
-                    >>>   }
+        **Examples**
+         Example meta_props for Training run creation in IBM Cloud Pak® for Data for Data version 3.0.1 or above:\n
+         >>> metadata = {
+         >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
+         >>>  client.training.ConfigurationMetaNames.DESCRIPTION: 'Hand-written Digit Recognition Training',
+         >>>  client.training.ConfigurationMetaNames.PIPELINE: {
+         >>>                "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
+         >>>                "rev": "12",
+         >>>                "model_type": "string",
+         >>>                "data_bindings": [
+         >>>                  {
+         >>>                    "data_reference_name": "string",
+         >>>                    "node_id": "string"
+         >>>                  }
+         >>>                ],
+         >>>                "nodes_parameters": [
+         >>>                  {
+         >>>                    "node_id": "string",
+         >>>                    "parameters": {}
+         >>>                  }
+         >>>                ],
+         >>>                "hardware_spec": {
+         >>>                  "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
+         >>>                  "rev": "12",
+         >>>                  "name": "string",
+         >>>                  "num_nodes": "2"
+         >>>                }
+         >>>      },
+         >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
+         >>>          'type': 's3',
+         >>>          'connection': {},
+         >>>          'location': {
+         >>>              'href': 'v2/assets/asset1233456',
+         >>>          }
+         >>>          "schema": "{ \"id\": \"t1\", \"name\": \"Tasks\", \"fields\": [ { \"name\": \"duration\", \"type\": \"number\" } ]}"
+         >>>      }],
+         >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+         >>>          'id' : 'string',
+         >>>          'connection': {
+         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+         >>>              'access_key_id': '***',
+         >>>              'secret_access_key': '***'
+         >>>          },
+         >>>          'location': {
+         >>>              'bucket': 'wml-dev-results',
+         >>>               'path' : "path"
+         >>>          }
+         >>>          'type': 's3'
+         >>>      }
+         >>>   }
 
-                    NOTE:  You can provide either one of the below values can be provided for training:
-                            client.training.ConfigurationMetaNames.EXPERIMENT
-                            client.training.ConfigurationMetaNames.PIPELINE
-                            client.training.ConfigurationMetaNames.MODEL_DEFINITION:
-                    Example meta_prop values for  training run creation in other versions:
-
-                    >>> metadata = {
-                    >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
-                    >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
-                    >>>          'connection': {
-                    >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-                    >>>              'access_key_id': '***',
-                    >>>              'secret_access_key': '***'
-                    >>>          },
-                    >>>          'source': {
-                    >>>              'bucket': 'wml-dev',
-                    >>>          }
-                    >>>          'type': 's3'
-                    >>>      }],
-                    >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
-                    >>>          'connection': {
-                    >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-                    >>>              'access_key_id': '***',
-                    >>>              'secret_access_key': '***'
-                    >>>          },
-                    >>>          'target': {
-                    >>>              'bucket': 'wml-dev-results',
-                    >>>          }
-                    >>>          'type': 's3'
-                    >>>      },
-                    >>> client.training.ConfigurationMetaNames.PIPELINE_UID : "/v4/pipelines/<PIPELINE-ID>"
-                    >>> }
-                    >>> training_details = client.training.run(definition_uid, meta_props=metadata)
-                    >>> training_uid = client.training.get_uid(training_details)
+         NOTE:  You can provide either one of the below values can be provided for training:\n
+         * client.training.ConfigurationMetaNames.EXPERIMENT\n
+         * client.training.ConfigurationMetaNames.PIPELINE\n
+         * client.training.ConfigurationMetaNames.MODEL_DEFINITION\n
+         Example meta_prop values for  training run creation in other versions:
 
+         >>> metadata = {
+         >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
+         >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
+         >>>          'connection': {
+         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+         >>>              'access_key_id': '***',
+         >>>              'secret_access_key': '***'
+         >>>          },
+         >>>          'source': {
+         >>>              'bucket': 'wml-dev',
+         >>>          }
+         >>>          'type': 's3'
+         >>>      }],
+         >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+         >>>          'connection': {
+         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+         >>>              'access_key_id': '***',
+         >>>              'secret_access_key': '***'
+         >>>          },
+         >>>          'target': {
+         >>>              'bucket': 'wml-dev-results',
+         >>>          }
+         >>>          'type': 's3'
+         >>>      },
+         >>> client.training.ConfigurationMetaNames.PIPELINE_UID : "/v4/pipelines/<PIPELINE-ID>"
+         >>> }
+         >>> training_details = client.training.run(definition_uid, meta_props=metadata)
+         >>> training_uid = client.training.get_uid(training_details)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -641,27 +640,26 @@ class Training(WMLResource):
         Cancel a training which is currently running and remove it. This method is also be used to delete metadata
         details of the completed or canceled training run when hard_delete parameter is set to True.
 
-            **Parameters**
+        **Parameters**
 
-            .. important::
-                #. **training_uid**:  Training UID\n
-                   **type**: str\n
+        .. important::
+            #. **training_uid**:  Training UID\n
+               **type**: str\n
 
-                 #. **hard_delete**: specify True or False.
-                                        True - To delete the completed or canceled training runs.
-                                        False - To cancel the currently running training run. Default value is False.
-                    **type**: Boolean\n
+            #. **hard_delete**: specify True or False.
+               True - To delete the completed or canceled training runs.
+               False - To cancel the currently running training run. Default value is False.
+               **type**: Boolean\n
 
-            **Output**
+        **Output**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. important::
+            **returns**: status ("SUCCESS" or "FAILED")\n
+            **return type**: str\n
 
-            **Example**
-
-             >>> client.training.cancel(training_uid)
+        **Example**
 
+         >>> client.training.cancel(training_uid)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -918,8 +916,6 @@ class Training(WMLResource):
 
             **Output**
 
-            **Output**
-
             .. important::
 
                 **returns**: None\n
