@@ -15,12 +15,10 @@
 from typing import TYPE_CHECKING, List, Union
 
 from ibm_watson_machine_learning.helpers.connections import (
-    DataConnection, S3Location, FSLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation,
+    DataConnection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation,
     DeploymentOutputAssetLocation)
 from ibm_watson_machine_learning.utils.autoai.enums import (DataConnectionTypes)
 
-from ibm_watson_machine_learning.utils.autoai.errors import DataLocationTypeNotSupported
-
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.workspace import WorkSpace
 
@@ -43,23 +41,19 @@ def validate_source_data_connections(source_data_connections: List['DataConnecti
             # note: save data as an data asset
             if workspace.wml_client.ICP:
                 asset_id = data_connection.location._save_file_as_data_asset(workspace=workspace)
-                data_connection.location = WMLSAssetLocation(
-                    asset_id) if workspace.WMLS else CP4DAssetLocation(asset_id)
+                data_connection.location = AssetLocation(asset_id)
                 data_connection.type = DataConnectionTypes.DS
             # --- end note
         elif isinstance(data_connection.location, WSDAssetLocation):
             # note: try to move local asset to server
             data_connection.location._move_asset_to_server(workspace=workspace)
             # --- end note
-
-        # note: set project id when we are working on CP4D and using Data Assets Location, space_id for WMLS
-        if isinstance(data_connection.location, WMLSAssetLocation):
-            data_connection.location.href = data_connection.location.href.format(
-                option='space_id',
-                id=workspace.wml_client.default_space_id)
-
-        elif isinstance(data_connection.location, CP4DAssetLocation):
-            if deployment:
+        elif isinstance(data_connection.location, AssetLocation) and data_connection.location._wsd:
+            # note: try to move local asset to server
+            data_connection.location._wsd_move_asset_to_server(workspace=workspace)
+            # --- end note
+        if isinstance(data_connection.location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation)):
+            if workspace.wml_client.default_space_id:
                 data_connection.location.href = data_connection.location.href.format(
                     option='space_id',
                     id=workspace.wml_client.default_space_id)
@@ -68,16 +62,6 @@ def validate_source_data_connections(source_data_connections: List['DataConnecti
                     option='project_id',
                     id=workspace.wml_client.default_project_id)
 
-        elif isinstance(data_connection.location, CloudAssetLocation):
-            if deployment:
-                data_connection.location.href = data_connection.location.href.format(
-                    option='space_id',
-                    id=workspace.wml_client.default_space_id)
-            else:
-                raise DataLocationTypeNotSupported(value_name='CloudAssetLocation',
-                                                   reason='Data asset type on Cloud is supported for Batch Deployment')
-        # -- end note
-
     return source_data_connections
 
 
@@ -148,7 +132,7 @@ def validate_deployment_output_connection(results_data_connection: Union['DataCo
                                                                  workspace=workspace)
     # -- end note
 
-    if isinstance(results_data_connection.location, (CP4DAssetLocation, WMLSAssetLocation)):
+    if isinstance(results_data_connection.location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation)):
         if workspace.wml_client.default_space_id:
             results_data_connection.location.path = results_data_connection.location.path.format(option='spaces',
                                                                                                  id=workspace.wml_client.default_space_id)
@@ -157,8 +141,8 @@ def validate_deployment_output_connection(results_data_connection: Union['DataCo
                                                                                                  id=workspace.wml_client.default_project_id)
 
     # note: results can be stored only on COS or CPD/WMLS DataAsset or DeploymentOutputAssetLocation
-    if not isinstance(results_data_connection.location, (S3Location, CP4DAssetLocation, WMLSAssetLocation, DeploymentOutputAssetLocation)):
+    if not isinstance(results_data_connection.location, (S3Location, AssetLocation, CP4DAssetLocation, WMLSAssetLocation, DeploymentOutputAssetLocation)):
         raise TypeError('Unsupported results location type. Results reference can be stored only in '
-                        'one of [S3Location, CP4DAssetLocation, WMLSAssetLocation, DeploymentOutputAssetLocation].')
+                        'one of [S3Location, AssetLocation, DeploymentOutputAssetLocation].')
     # -- end
     return results_data_connection
